library(readr)
library(tidyverse)
library(magrittr)
library(readxl)
library(WGCNA)

setwd("Y:/EKID/DRNG8/ESE00110_P301S_TauTg_Proteomics/Analysis/kid81475/SC/ProteinGroups/WGCNA/module_preservationAnalysis/hADbrain")

## ID conversion ## Human -> Mouse

# tautg dataset
tautg_input = read_delim("tautg_input.txt", "\t", escape_double = FALSE, trim_ws = TRUE) %>%
  filter(use == TRUE)

# human AD dataset
hAD_input = read_delim("hAD_input.txt", "\t", escape_double = FALSE, trim_ws = TRUE) %>%
  filter(use == TRUE) %>%
  filter(ms_ac != "NA")

# tautg modules
tautgModules = tautg_input %>% 
  filter(use == TRUE) %>%
  pull(moduleColors)

### module preservation analysis ###
# matrices for analysis
tautg_dat = tautg_input %>%
  select(9:ncol(.)) %>%
  as.data.frame() %>%
  set_rownames(tautg_input$mouse_canonical)

hAD_dat = hAD_input %>%
  select(10:ncol(.)) %>%
  as.data.frame() %>%
  set_rownames(hAD_input$ms_ac)

#In this section we use the function modulePreservation to study module preservation of female modules in the male
#data. The function call is simple and most of this section will be devoted to the analysis of the results. We now set
#up the multi-set expression data and corresponding module colors:

setLabels = c("tatutg_SC", "hAD");
multiExpr = list(tautg_SC = list(data = t(tautg_dat)), hAD = list(data = t(hAD_dat)));
multiColor = list(tautg_SC = tautgModules);

#Roll the drums, here comes the calculation of module preservation. This calculation takes about 45 minutes on a
#fast desktop PC. If this code has been already executed once and the result is saved, it can be loaded from disk, thus
#saving time.

system.time( {
  mp = modulePreservation(multiExpr, multiColor,
                          referenceNetworks = 1,
                          nPermutations = 200,
                          randomSeed = 1,
                          quickCor = 0,
                          verbose = 3)
} );
# Save the results
save(mp, file = "modulePreservation.RData");  


#We now analyze the data. Isolate the observed statistics and their Z scores:
ref = 1
test = 2

statsObs = cbind(mp$quality$observed[[ref]][[test]][, -1], mp$preservation$observed[[ref]][[test]][, -1])
statsZ = cbind(mp$quality$Z[[ref]][[test]][, -1], mp$preservation$Z[[ref]][[test]][, -1]);

#We look at the main output: the preservation medianRank and Zsummary statistics.
# Compare preservation to quality:
print( cbind(statsObs[, c("medianRank.pres", "medianRank.qual")],
             signif(statsZ[, c("Zsummary.pres", "Zsummary.qual")], 2)) )
#The numbers are nice, but (to paraphrase a saying) a picture is worth a thousand numbers. We plot the preservation
#medianRank and Zsummary for the female modules as a function of module size. The plotting code may seem a bit
#involved, but it is worth going through.

# Module labels and module sizes are also contained in the results
modColors = rownames(mp$preservation$observed[[ref]][[test]])
moduleSizes = mp$preservation$Z[[ref]][[test]][, 1];
# leave grey and gold modules out
plotMods = !(modColors %in% c("grey", "gold"));
# Text labels for points
text = modColors[plotMods];
# Auxiliary convenience variable
plotData = cbind(mp$preservation$observed[[ref]][[test]][, 2], mp$preservation$Z[[ref]][[test]][, 2])
# Main titles for the plot
mains = c("Preservation Median rank", "Preservation Zsummary");
# Start the plot
sizeGrWindow(10, 5);
#pdf(fi="Plots/BxHLiverFemaleOnly-modulePreservation-Zsummary-medianRank.pdf", wi=10, h=5)
par(mfrow = c(1,2))
par(mar = c(4.5,4.5,2.5,1))
for (p in 1:2)
{
  min = min(plotData[, p], na.rm = TRUE);
  max = max(plotData[, p], na.rm = TRUE);
  # Adjust ploting ranges appropriately
  if (p==2)
  {
    if (min > -max/10) min = -max/10
    ylim = c(min - 0.1 * (max-min), max + 0.1 * (max-min))
  } else
    ylim = c(max + 0.1 * (max-min), min - 0.1 * (max-min))
  plot(moduleSizes[plotMods], plotData[plotMods, p], col = 1, bg = modColors[plotMods], pch = 21,
       main = mains[p],
       cex = 2.4,
       ylab = mains[p], xlab = "Module size", log = "x",
       ylim = ylim,
       xlim = c(10, 2000), cex.lab = 1.2, cex.axis = 1.2, cex.main =1.4)
  labelPoints(moduleSizes[plotMods], plotData[plotMods, p], text, cex = 1, offs = 0.08);
  # For Zsummary, add threshold lines
  if (p==2)
  {
    abline(h=0)
    abline(h=2, col = "blue", lty = 2)
    abline(h=10, col = "darkgreen", lty = 2)
  }
}
# If plotting into a file, close it
dev.off();

statsZoutput = tibble(rownames(statsZ)) %>%
  cbind(tibble(statsZ))
colnames(statsZoutput)[1] = "module"
write.table(statsZoutput, "statsZ.txt", sep = "\t", quote = FALSE, row.names = FALSE, col.names = TRUE)

